function f = land(v)
%   f = land(v)
%
%   is a defect function for the design of a landscape lens.
%
%   The variables are
%
%       v(1) = first surface curvature
%       v(2) = distance to stop
%
%   The defects are
%
%       f(1) = coma
%       f(2) = astigmatism

%   Written by: John S. Loomis, University of Dayton
%   Revision: 8 Feb 2003

global cv th rn;
cv(2)=v(1); % first surface curvature
th(3)=v(2); % distance to stop
yap = 5.0;
uco = tan(10*pi/180);
scl = yap^2/2;
ya = parax([yap 0],cv,th,rn);
usolve = -0.125;
m=3;
yn=ya(m,1);
if (abs(yn)>1e-6)
    cv(m)= -(rn(m)*usolve-rn(m-1)*ya(m-1,2))/((rn(m)-rn(m-1))*yn);
end
ya(m,2)=usolve;
ya = parax([yap 0],cv,th,rn);
yc = parax([0 uco],cv,th,rn);
k = -yc(4,1)/ya(4,1);
yc = yc + k*ya;
lambda = 0.006;
w = ford(ya,yc,cv,th,rn,lambda);
f(1) = w(2); % coma
f(2) = w(3); % astigmatism
f = f';